function commonSubmitArgs = getCommonSubmitArgs(cluster, numWorkers)
% Get any additional submit arguments for the Slurm sbatch command
% that are common to both independent and communicating jobs.

% wiki: 

% Copyright 2010-2017 The MathWorks, Inc.

commonSubmitArgs = sprintf('-l license_mdcs=%d', numWorkers);
currFilename = mfilename;

ppn = validatedPropValue(cluster, 'ProcsPerNode', 'double');
if isempty(ppn) || ppn <= 0
    % Default ppn count.
    ppn = 8;
end

% Don't request more cores/node than workers
ppn = min(numWorkers,ppn);
% Determine number of nodes
numberOfNodes = ceil(numWorkers/ppn);
commonSubmitArgs = sprintf('%s -l nodes=%d:ppn=%d', commonSubmitArgs, numberOfNodes, ppn);
dctSchedulerMessage(4, '%s: Requesting %d nodes with %d processors per node', currFilename, ...
                    numberOfNodes, ppn);


%% REQUIRED

% Specify a WallTime
wt = validatedPropValue(cluster, 'WallTime', 'char');
if isempty(wt)
    
    emsg = sprintf(['\n\t\t>> %% Must set a Walltime (HH:MM:SS) before submitting jobs\n', ...
    '\t\t>> c = parcluster;\n', ...
    '\t\t>> c.AdditionalProperties.WallTime = ''00:60:00'';\n', ...
    '\t\t>> c.saveProfile\n']);

      error(emsg) %#ok<SPERR>
else
      commonSubmitArgs = [commonSubmitArgs ' -l walltime=' wt];
end


%% OPTIONAL

% Queue name
qn = validatedPropValue(cluster, 'QueueName', 'char');
if ~isempty(qn)
    commonSubmitArgs = [commonSubmitArgs ' -q ' qn];
end

% % Walltime
%  wt = validatedPropValue(cluster, 'WallTime', 'char');
%  if ~isempty(wt)
%      commonSubmitArgs = [commonSubmitArgs ' -l walltime=' wt];
%  end

% Email notification
ea = validatedPropValue(cluster, 'EmailAddress', 'char');
if ~isempty(ea)
    % User wants to be emailed the job status
    commonSubmitArgs = [commonSubmitArgs ' -M ' ea ' -m abe'];
end

% Every job is going to require a certain number of MDCS licenses.
% The Native RM job submission language provides a direct method of
% license specification.
%
% Moab:
%  1. Copy
%          $MOABHOMEDIR/tools/flexlm/license.mon.flexLM.pl
%     to
%          $MOABHOMEDIR/tools/flexlm/license.mon.matlab.flexLM.pl
%
%  2. Modify license.mon.matlab.flexLM.pl
%
%      my @FLEXlmCmds = ("/.../matlab/etc/glnxa64/lmutil lmstat -a -c /.../matlab/licenses/network.lic");
%
%  3. On u-003-scfe03, modify $MOABHOMEDIR/.../moab.cfg
%
%      RMCFG[FLEXlm1]     TYPE=NATIVE RESOURCETYPE=LICENSE
%      RMCFG[FLEXlm1]     CLUSTERQUERYURL=exec://$TOOLSDIR/flexlm/license.mon.matlab.flexLM.pl
%
% commonSubmitArgs = sprintf('%s -l software=MATLAB_Distrib_Comp_Engine:%d',commonSubmitArgs,w);

% Catch-all
asa = validatedPropValue(cluster, 'AdditionalSubmitArgs', 'char');
if ~isempty(asa)
    commonSubmitArgs = [commonSubmitArgs ' ' asa];
end
